/*
** Module   : ScrollEvent.java
** Abstract : Scroll event.
**
** Copyright (c) 2010-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ------------------------------Description----------------------------
** 001 SIY 20100629          Created initial version
** 002 SIY 20100804          Changes in imports, some refactorings.
** 003 EVL 20150526          Adding flag to separate scrolling by mouse from scrolling by keyboard
**                           for the cases when it is important.
*/

package com.goldencode.p2j.ui.client.event;

import com.goldencode.p2j.ui.client.*;
import com.goldencode.p2j.ui.client.widget.*;

/**
 * Scroll event.
 */
public class ScrollEvent
extends Event
{
   /** Scroll direction. */
   private final ScrollDirection direction;

   /** Scroll limits. */
   private final Point limit;
   
   /** Is the mouse the origin of the event or keyboard. */
   private final boolean isMouseOrigin;

   /**
    * Constructor.
    * 
    * @param   source
    *          Event source.
    * @param   direction
    *          Scroll direction.
    * @param   limit
    *          Scroll limits.
    */
   public ScrollEvent(Widget source, ScrollDirection direction, Point limit)
   {
      super(source, EventType.SCROLL_EVENT);
      this.direction = direction;
      this.limit = limit;
      this.isMouseOrigin = false;
   }

   /**
    * Constructor.
    * 
    * @param   source
    *          Event source.
    * @param   direction
    *          Scroll direction.
    * @param   limit
    *          Scroll limits.
    * @param   isMouseOrigin
    *          If the event origin is mouse.
    */
   public ScrollEvent(Widget source,
                      ScrollDirection direction,
                      Point limit,
                      boolean isMouseOrigin)
   {
      super(source, EventType.SCROLL_EVENT);
      this.direction = direction;
      this.limit = limit;
      this.isMouseOrigin = isMouseOrigin;
   }

   /**
    * Get scroll event direction.
    * 
    * @return  direction.
    */
   public ScrollDirection direction()
   {
      return direction;
   }

   /**
    * Get scroll event limit.
    * 
    * @return  limit.
    */
   public Point limit()
   {
      return limit;
   }

   /**
    * Get origin of the scroll event.
    * 
    * @return  <CODE>TRUE</CODE> if the mouse is the event origin, <CODE>FALSE</CODE> otherwise.
    */
   public boolean isMouseOrigin()
   {
      return isMouseOrigin;
   }

   /**
    * Return instance of {@link Scrollable} which is the source of this event.
    *  
    * @return  reference to {@link Scrollable} or <code>null</code> if 
    *          source does not implement this interface.
    */
   public Scrollable scrollable()
   {
      Widget src = super.source();
      
      if (src instanceof Scrollable) 
         return (Scrollable) src;
      
      return null;
   }
}
